module Opsmgr
  class BoshCommandRunner
    def initialize(bosh_command:, logger:)
      @bosh_command = bosh_command
      @logger = logger
    end

    def run(command)
      system_or_fail(
        "#{bosh_command_prefix} #{command}",
        "bosh #{command} failed"
      )
    end

    def run_and_capture_output(command)
      capture_output_or_fail(
        "#{bosh_command_prefix} #{command}",
        "bosh #{command} failed"
      )
    end

    def run_with_deployment(command, deployment)
      bosh_deployment = bosh_deployments[/#{deployment}-[0-9a-f]{8,}/]
      fail 'Deployment not found' unless bosh_deployment

      deployment_file = "#{ENV.fetch('TMPDIR', '/tmp')}/#{deployment}.yml"

      begin
        run(
          "-n download manifest #{bosh_deployment} #{deployment_file}"
        )
      rescue RuntimeError
        raise 'bosh download manifest failed'
      end

      run("-d #{deployment_file} #{command}")
    end

    private

    def bosh_deployments
      run_and_capture_output('deployments')
    rescue RuntimeError
      raise 'bosh deployments failed'
    end

    def system_or_fail(command, failure_message)
      clean_and_log(command)
      Bundler.clean_system(command) || fail(failure_message)
    end

    def capture_output_or_fail(command, failure_message)
      clean_and_log(command)

      Bundler.with_clean_env do
        output, status = Open3.capture2(command)
        fail(failure_message) unless status.success?
        output
      end
    end

    def clean_and_log(command)
      scrubbed_command = command.slice(command.index('bosh')..-1)
      scrubbed_command.sub!(/\s\-p\s\b\w+\b/, ' -p <PASSWORD>')
      scrubbed_command.sub!(/\s\-u\s\b\w+\b/, ' -u <USER>')

      logger.info("Running #{scrubbed_command}")
    end

    def bosh_command_prefix
      @bosh_command_prefix ||= bosh_command.command
    end

    attr_reader :bosh_command, :logger
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
