require 'backport_refinements'
using OpsManagerUiDrivers::BackportRefinements

require 'opsmgr/log'

module Opsmgr
  module Cmd
    class OpsManager
      include Loggable

      def initialize(target_environment)
        @environment = target_environment
      end

      def configure_microbosh_infrastructure(client)
        result = client.installation_settings
        return unless result.success?

        result = result.as_hash
        return if result.fetch('installation_version', '') != '1.4'
        return if result['infrastructure']['type'] != 'vsphere'

        result['infrastructure']['file_system'] = {
          'microbosh_vm_folder' => environment.settings.dig('name'),
          'microbosh_template_folder' => environment.settings.dig('name'),
          'microbosh_disk_path' => environment.settings.dig('name'),
        }

        file = Tempfile.new('om_install_settings')
        file.write(YAML.dump(result))
        file.close

        client.upload_product_installation_settings(file.path)
      end

      def delete_unused_products(client)
        result = client.delete_unused_products
        if result.success?
          log.info 'Successfully deleted unused products'
        else
          fail result.message
        end
      end

      def upload_product(client, path)
        result = client.upload_component(path)
        if result.success?
          log.info 'Successfully uploaded product'
        else
          fail result.message
        end
      end

      def list_products(client)
        result = client.list_products
        if result.success?
          result
        else
          fail result.message
        end
      end

      def add_product(client, name, version)
        result = client.add_product(name, version)
        if result.success?
          log.info 'Successfully added product'
        else
          fail result.message
        end
      end

      def upgrade_product(client, guid, version)
        result = client.upgrade_product(guid, version)
        if result.success?
          log.info 'Successfully upgraded product'
        else
          fail result.message
        end
      end

      def installed_products(client)
        result = client.installed_products
        if result.success?
          result
        else
          fail result.message
        end
      end

      def import_installation(client, path)
        result = client.import_installation(path, environment.settings.dig('ops_manager', 'password'))
        if result.success?
          log.info 'Successfully imported installation'
        else
          fail result.message
        end
      end

      def import_stemcell(client, path)
        result = client.import_stemcell(path)
        if result.success?
          log.info 'Successfully imported stemcell'
        else
          fail result.message
        end
      end

      def download_staged_manifest(client, guid, manifest_filepath)
        result = client.download_staged_manifest(guid)
        if result.success?
          File.open(manifest_filepath, 'w') do |mf|
            mf.write(result.manifest)
          end
          log.info 'Successfully downloaded staged manifest for product'
        else
          fail result.message
        end
      end

      def revert_staged_changes(client)
        result = client.revert_staged_changes
        if result.success?
          log.info 'Successfully reverted staged changes'
        else
          fail result.message
        end
      end

      private

      attr_reader :environment
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
