require 'opsmgr/bosh_command_runner'
require 'open3'

module Opsmgr
  class ErrandRunner
    def initialize(bosh_command:, environment_name:, logger:, product_name:, errand_name:, download_logs:)
      @bosh_command = bosh_command
      @environment_name = environment_name
      @logger = logger
      @product_name = product_name
      @errand_name = errand_name
      @download_logs = download_logs ? "--download-logs" : ""

      @bosh_command_runner = Opsmgr::BoshCommandRunner.new(
        bosh_command: @bosh_command,
        logger: @logger
      )
    end

    def run_errand
      deployments_output = begin
        @bosh_command_runner.run_and_capture_output('deployments')
      rescue RuntimeError
        raise 'bosh deployments failed'
      end

      bosh_deployment = deployments_output[/#{@product_name}-[0-9a-f]{8,}/]

      fail 'Deployment not found' if bosh_deployment.nil?

      deployment_file = "#{ENV.fetch('TMPDIR', '/tmp')}/#{environment_name}.yml"

      begin
        @bosh_command_runner.run(
          "-n download manifest #{bosh_deployment} #{deployment_file}"
        )
      rescue RuntimeError
        raise 'bosh download manifest failed'
      end

      begin
        @bosh_command_runner.run(
          "-d #{deployment_file} run errand #{@errand_name} #{@download_logs}"
        )
      rescue RuntimeError
        raise "Errand #{@errand_name} failed"
      end
    end

    private

    attr_reader :bosh_command, :environment_name, :logger, :product_name, :errand_name, :download_logs
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
