require 'logger'

module Opsmgr
  class << self
    def log
      Log.instance
    end

    def logger_for(progname)
      LoggerWithProgName.new(progname)
    end
  end

  module Loggable
    def log
      @logger ||= LoggerWithProgName.new(self.class.name)
    end

    def self.included(other_module)
      def other_module.log
        @logger ||= LoggerWithProgName.new(name)
      end
    end
  end

  class Log
    class << self
      def instance
        @instance || fail('Logging attempted without being configured first!')
      end

      def test_mode!
        log_path = '/tmp/opsmgr_test.log'
        File.open(log_path, 'w') {} # empty out the file in a cross-platform-safe way
        @instance = ::Logger.new(log_path, File::WRONLY | File::APPEND)
        instance.sev_threshold = ::Logger::DEBUG
      end

      def stdout_mode!
        STDOUT.sync = true
        @instance = ::Logger.new(STDOUT)
        instance.sev_threshold = ::Logger.const_get(ENV.fetch('LOG_LEVEL', 'INFO'))
      end
    end
  end

  class LoggerWithProgName
    def initialize(progname)
      @progname = progname
    end

    %w(debug info warn error fatal).map(&:to_sym).each do |level|
      define_method(level) do |message|
        Log.instance.public_send(level, progname) { message }
      end
    end

    private

    attr_reader :progname
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
