require 'opsmgr/ui_helpers/ui_spec_runner'
require 'opsmgr/environments'
require 'opsmgr/cmd/ops_manager'
require 'opsmgr/api/client'

class ProductUploadWrapper
  def self.wrap_add(environment:, product_path:, product_name:, om_version:)
    wrap_operation(environment, product_path, product_name, 'add', om_version)
  end

  def self.wrap_upgrade(environment:, product_path:, product_name:, om_version:)
    wrap_operation(environment, product_path, product_name, 'upgrade', om_version)
  end

  def self.wrap_upload(environment:, product_path:, product_name:, om_version:)
    wrap_operation(environment, product_path, product_name, 'upload', om_version)
  end

  def self.wrap_operation(environment, product_path, product_name, operation, om_version)
    unless %w(add upgrade upload).include?(operation)
      fail "Operation '#{operation}' is not available"
    end

    environment_object = Opsmgr::Environments.for(environment)
    client = Opsmgr::Api::Client.new(environment_object, om_version)
    opsmgr_cmd = Opsmgr::Cmd::OpsManager.new(environment_object)
    opsmgr_cmd.upload_product(client, product_path)

    products_list = opsmgr_cmd.list_products(client)

    stored_version = find_latest_version(product_name, products_list)

    fail "#{product_name} is not available" if stored_version.nil?

    return if operation == 'upload'

    if operation == 'add'
      opsmgr_cmd.add_product(client, product_name, stored_version)
    else
      installed_products = opsmgr_cmd.installed_products(client)
      product_guid = installed_products.guid_for(product_name)
      opsmgr_cmd.upgrade_product(client, product_guid, stored_version)
    end
  end

  def self.find_latest_version(product_name, products_list)
    stored_version = nil

    products_list.products.each do |p|
       if p['name'] != product_name
         next
       end

       if stored_version.nil?
         stored_version = p['product_version']
       elsif Gem::Version.new(p['product_version']) > Gem::Version.new(stored_version)
         stored_version = p['product_version']
       end
    end

    stored_version
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
