require 'yaml'
require 'opsmgr/settings/microbosh/product'
require 'opsmgr/log'

module Opsmgr
  module Settings
    module Microbosh
      class InstallationSettings
        include Loggable

        def self.from_api_result(result)
          new(result.as_hash)
        end

        def initialize(installation_hash)
          @installation_hash = installation_hash
        end

        def product(product_name)
          products.find { |p| p.name == product_name }
        end

        def network_guid(network_name)
          networks = installation_hash.fetch('infrastructure', {}).fetch('networks', [])
          matching_network = networks.find { |network| network['name'] == network_name }

          if matching_network.nil?
            available_network_names = networks.map { |network| network['name'] }
            log.warn("No network matching name #{network_name}. Available names: #{available_network_names.join(', ')}")
            return nil
          end

          matching_network.fetch('guid')
        end

        def default_availability_zone_guid
          first_zone = installation_hash.fetch('infrastructure', {}).fetch('availability_zones', []).first
          first_zone['guid'] if first_zone
        end

        def availability_zone_guid(zone_name)
          zones = installation_hash.fetch('infrastructure', {}).fetch('availability_zones', [])
          matching_zone = zones.find do |zone|
            zone['name'] == zone_name
          end

          if matching_zone.nil?
            available_zone_names = zones.map { |network| network['name'] }
            log.warn("No availability zone matching name #{zone_name}. Available names: #{available_zone_names.join(', ')}")
            return nil
          end

          matching_zone.fetch('guid')
        end

        def to_yaml
          YAML.dump(installation_hash)
        end

        private

        attr_reader :installation_hash

        def products
          if installation_hash.key?('components')
            installation_hash.fetch('components').map { |h| Opsmgr::Settings::Microbosh::Product.new(h) }
          elsif installation_hash.key?('products')
            installation_hash.fetch('products').map { |h| Opsmgr::Settings::Microbosh::Product.new(h) }
          else
            fail 'Unknown Ops Manager installation schema. Please check Ops Manager version.'
          end
        end
      end
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
