require 'opsmgr/settings/microbosh/property'

module Opsmgr
  module Settings
    module Microbosh
      class Job
        def initialize(job_hash)
          @job_hash = job_hash
        end

        def name
          job_hash.fetch('identifier')
        rescue
          job_hash.fetch('type')
        end

        def property(property_name)
          properties('properties').find { |property| property.name == property_name }
        end

        def resource(resource_name)
          properties('resources').find { |resource| resource.name == resource_name }
        end

        def networks=(networks)
          job_hash['network_references'] = networks
        end

        def elb_name=(name)
          job_hash['elb_name'] = name
        end

        def instances=(instance_count)
          job_hash['instances'].first['value'] = instance_count
          job_hash.delete('partitions')
        end

        private

        attr_reader :job_hash

        def properties(key)
          job_hash[key].map { |property| Opsmgr::Settings::Microbosh::Property.new(property) }
        end
      end
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
