require 'opsmgr/settings/microbosh/job'

module Opsmgr
  module Settings
    module Microbosh
      class Product
        attr_reader :product_hash

        def initialize(product_hash)
          @product_hash = product_hash
        end

        def guid
          product_hash.fetch('guid')
        end

        def name
          product_hash.fetch('identifier')
        rescue
          product_hash.fetch('type')
        end

        def disabled_post_deploy_errand_names(errands = nil)
          product_hash['disabled_post_deploy_errand_names'] = errands
        end

        def availability_zone_references=(zones_array)
          product_hash['availability_zone_references'] = zones_array
        end

        def singleton_availability_zone=(value)
          product_hash['singleton_availability_zone_reference'] = value
        end

        def network_reference=(network_references)
          product_hash['network_reference'] = network_references
        end

        def set_property(name, value)
          property(name)['value'] = value
        end

        def for_job(job_name)
          job_result = job(job_name)
          yield job_result if job_result
        end

        def job(job_name)
          jobs.find { |job| job.name == job_name }
        end

        def jobs
          product_hash['jobs'].map { |h| Opsmgr::Settings::Microbosh::Job.new(h) }
        end

        def product_version
          product_hash['product_version']
        end

        def singleton_availability_zone
          product_hash['singleton_availability_zone_reference']
        end

        def property(name)
          return nil if properties.empty?
          key = properties.first['identifier'] ? 'identifier' : 'definition'
          properties.find { |property| property[key] == name }
        end

        private

        def properties
          product_hash['properties'] ||= []
        end

        def has_property?(property)
          properties.find_index(property) != -1
        end
      end
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
