require_relative 'config_helper'

RSpec.describe 'Deleting the installation', order: :defined do
  let!(:current_ops_manager) { ops_manager_driver }
  let!(:env_settings) { fetch_environment_settings }

  it 'creates the admin user and logs in' do
    # if the ops manager is not up, fail earlier than other cases and
    # let the caller handle the error
    poll_up_to_mins(1) do
      current_ops_manager.setup_page.setup_or_login(
        user: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )

      expect(page).to have_content('Installation Dashboard')
    end
  end

  it 'deletes the installation' do
    if current_ops_manager.product_dashboard.delete_installation_available?
      current_ops_manager.product_dashboard.delete_whole_installation

      expect(current_ops_manager.product_dashboard).not_to be_delete_installation_available

      poll_up_to_mins(45) do
        expect(current_ops_manager.state_change_progress).to be_state_change_success
      end
    else
      puts 'no installation to delete'
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
