require_relative 'config_helper'

RSpec.describe 'Reverting staged changes', order: :defined do
  let!(:current_ops_manager) { ops_manager_driver }
  let!(:env_settings) { fetch_environment_settings }

  it 'creates the admin user and logs in' do
    # if the ops manager is not up, fail earlier than other cases and
    # let the caller handle the error
    poll_up_to_mins(1) do
      current_ops_manager.setup_page.setup_or_login(
        user: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )

      expect(page).to have_content('Installation Dashboard')
    end
  end

  it 'reverts staged changes' do
    if current_ops_manager.product_dashboard.revert_available?
      current_ops_manager.product_dashboard.revert_pending_changes

      poll_up_to_mins(1) do
        expect(current_ops_manager.product_dashboard.revert_available?).to eq false
      end
    else
      puts 'no staged changes to revert'
    end
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
