require 'capybara/webkit'
require 'capybara/dsl'
require 'json'

module SettingsHelper
  def product_path
    ENV.fetch('PRODUCT_PATH')
  end

  def product_name
    ENV.fetch('PRODUCT_NAME')
  end

  def export_destination_path
    ENV.fetch('EXPORT_DESTINATION')
  end

  def import_file_path
    ENV.fetch('IMPORT_FILE')
  end

  def stemcell_file_path
    ENV.fetch('STEMCELL_FILE')
  end

  def om_version
    ENV.fetch('OM_VERSION')
  end

  def install_timeout
    ENV.fetch('INSTALL_TIMEOUT').to_i
  end

  def delete_timeout
    Integer(ENV.fetch('DELETE_TIMEOUT'))
  end

  def errand_names
    JSON.parse(ENV.fetch('ERRAND_NAMES'))
  end

  def poll_interval
    ENV.fetch('POLL_INTERVAL').to_i
  end


  def ops_manager_driver
    fail 'Include OpsManagerUiDrivers::PageHelpers' unless respond_to? :fetch_environment_settings

    configure_capybara(fetch_environment_settings['ops_manager']['url'])
    ops_manager_url = fetch_environment_settings['ops_manager']['url']
    case om_version
    when '1.4'
      om_1_4(ops_manager_url)
    when '1.5'
      om_1_5(ops_manager_url)
    when '1.6'
      om_1_6(ops_manager_url)
    when '1.7'
      om_1_7(ops_manager_url)
    when '1.8'
      om_1_8(ops_manager_url)
    else
      fail "Unsupported Ops Manager Version #{om_version.inspect}"
    end
  end

  def ops_manager_api_driver
    fail 'Include OpsManagerUiDrivers::PageHelpers' unless respond_to? :fetch_environment_settings

    env_settings = fetch_environment_settings
    case om_version
    when '1.4'
      api_1_4(
        host: env_settings['ops_manager']['url'],
        username: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )
    when '1.5'
      api_1_5(
        host: env_settings['ops_manager']['url'],
        username: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )
    when '1.6'
      api_1_6(
        host: env_settings['ops_manager']['url'],
        username: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )
    when '1.7'
      api_1_7(
        host: env_settings['ops_manager']['url'],
        username: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )
    when '1.8'
      api_1_8(
        host: env_settings['ops_manager']['url'],
        username: env_settings['ops_manager']['username'],
        password: env_settings['ops_manager']['password'],
      )
    else
      fail "Unsupported Ops Manager Version #{om_version.inspect}"
    end
  end

  def environment_name
    ENV.fetch('ENVIRONMENT_NAME')
  end

  def fetch_environment_settings
    Opsmgr::Environments.for(environment_name).settings
  end

  def configure_capybara(ops_manager_url)
    Capybara.configure do |c|
      c.default_driver = :webkit
    end

    begin
      Capybara::Webkit.configure do |c|
        c.allow_url(ops_manager_url)
        c.ignore_ssl_errors
      end
    rescue
      # Capybara says, "All configuration must take place before the driver starts"
    end

    page.current_window.resize_to(1024, 3000) # avoid overlapping footer spec failures
  end
end
