require 'rspec'

class UiSpecRunner
  def initialize(environment:, om_version:)
    raise 'No Environment Name provided' if environment.nil? || environment.empty?
    raise 'No Ops Manager Version provided' if om_version.nil? || om_version.empty?

    ENV['ENVIRONMENT_NAME'] = environment
    ENV['OM_VERSION'] = om_version
  end

  def add_first_user
    run_spec([spec_path + '/add_first_user_spec.rb'])
  end

  def configure_microbosh
    run_spec([microbosh_spec_path + '/configure_microbosh_spec.rb'])
  end

  def trigger_install(install_timeout, poll_interval)
    ENV['INSTALL_TIMEOUT'] = install_timeout
    ENV['POLL_INTERVAL'] = poll_interval

    run_spec([spec_path + '/trigger_install_spec.rb'])
  end

  def get_latest_install_log
    run_spec([spec_path + '/get_latest_install_log_spec.rb'])
  end

  def upload_and_add_product(product_path, product_name)
    ENV['PRODUCT_PATH'] = product_path
    ENV['PRODUCT_NAME'] = product_name

    run_spec([spec_path + '/upload_and_add_product_spec.rb'])
  end

  def upload_and_upgrade_product(product_path, product_name)
    ENV['PRODUCT_PATH'] = product_path
    ENV['PRODUCT_NAME'] = product_name

    run_spec([spec_path + '/upload_and_upgrade_product_spec.rb'])
  end

  def export_installation(export_destination)
    ENV['EXPORT_DESTINATION'] = export_destination

    run_spec([spec_path + '/export_installation_spec.rb'])
  end

  def post_import_configuration
    run_spec([spec_path + '/post_import_configuration_spec.rb'])
  end

  def delete_installation
    run_spec([spec_path + '/delete_installation_spec.rb'])
  end

  def delete_product(product_name, timeout, poll_interval)
    ENV['PRODUCT_NAME'] = product_name
    ENV['DELETE_TIMEOUT'] = timeout
    ENV['POLL_INTERVAL'] = poll_interval

    run_spec([spec_path + '/delete_product_spec.rb'])
  end

  def delete_product_if_present(product_name, timeout, poll_interval)
    ENV['PRODUCT_NAME'] = product_name
    ENV['DELETE_TIMEOUT'] = timeout
    ENV['POLL_INTERVAL'] = poll_interval

    run_spec([spec_path + '/delete_product_if_present_spec.rb'])
  end

  def import_stemcell(stemcell_file, product_name)
    ENV['STEMCELL_FILE'] = stemcell_file
    ENV['PRODUCT_NAME'] = product_name

    run_spec([spec_path + '/import_stemcell_spec.rb'])
  end

  def uncheck_errands(product_name, errand_names)
    require 'json'

    ENV['PRODUCT_NAME'] = product_name
    ENV['ERRAND_NAMES'] = JSON.generate(errand_names)

    run_spec([spec_path + '/uncheck_errands_spec.rb'])
  end

  def revert_staged_changes
    run_spec([spec_path + '/revert_staged_changes_spec.rb'])
  end

  private

  def spec_path
    File.dirname(__FILE__)
  end

  def microbosh_spec_path
    File.join(spec_path, 'microbosh')
  end

  def run_spec(spec_to_run)
    RSpecExiter.exit_rspec(RSpec::Core::Runner.run(spec_to_run))
  end
end

module RSpecExiter
  def self.exit_rspec(exit_code)
    exit exit_code
  end
end
# Copyright (c) 2014-2015 Pivotal Software, Inc.
# All rights reserved.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
# USE OR OTHER DEALINGS IN THE SOFTWARE.
